(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    531720,      10231]
NotebookOptionsPosition[    517836,       9824]
NotebookOutlinePosition[    520967,       9906]
CellTagsIndexPosition[    520844,       9900]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[TextData[{
 "Regularity vs. complexity\nin the binary representation of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["3", "n"], TraditionalForm]], "None"]
}], "Title",
 CellChangeTimes->{{3.434326585437378*^9, 3.4343265856043777`*^9}, {
  3.434326679727378*^9, 3.434326699701378*^9}}],

Cell["a haunted tale of unreal numbers", "Subtitle",
 CellChangeTimes->{{3.434328086720378*^9, 3.4343280939873776`*^9}, {
  3.434328237597378*^9, 3.4343282393763776`*^9}, {3.4343298718391776`*^9, 
  3.4343298719171777`*^9}}],

Cell[TextData[{
 "Eric Rowland\nDepartment of Mathematics, Rutgers University\n",
 ButtonBox["http://math.rutgers.edu/~erowland/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://math.rutgers.edu/~erowland/"], None}]
}], "Subsubtitle",
 CellChangeTimes->{{3.434364070630945*^9, 3.4343640708649454`*^9}, {
  3.434364325583745*^9, 3.434364329530545*^9}, {3.4344133687785997`*^9, 
  3.4344134277466*^9}, {3.4344888322468*^9, 3.4344888848654003`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Basic structure", "Section",
 CellChangeTimes->{3.434031051078262*^9, 3.434032385049862*^9}],

Cell["\<\
Powers of 3 in binary show other local features.
But overall we get an impression of uniform disorder; there is no global \
structure evident.\
\>", "Text",
 CellChangeTimes->{{3.434032410587062*^9, 3.434032422879862*^9}, {
  3.434394539102151*^9, 3.4343945393673506`*^9}}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"IntegerDigits", "[", 
   RowBox[{
    SuperscriptBox["3", 
     RowBox[{"Range", "[", 
      RowBox[{"0", ",", "255"}], "]"}]], ",", "2", ",", "700"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.434030514469462*^9, 3.434030514609862*^9}, {
  3.4340305636718616`*^9, 3.4340305638590617`*^9}, {3.4340308499006615`*^9, 
  3.434030851101862*^9}, {3.434031924116662*^9, 3.434031940839862*^9}, {
  3.4343956814277506`*^9, 3.434395681661751*^9}}],

Cell["\<\
For reasons that will be clear later, let's reflect the image.\
\>", "Text",
 CellChangeTimes->{{3.433855434085148*^9, 3.4338554570483475`*^9}, {
  3.434032146759862*^9, 3.434032148101462*^9}}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     SuperscriptBox["3", 
      RowBox[{"Range", "[", 
       RowBox[{"0", ",", "255"}], "]"}]], ",", "2", ",", "700"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4338554770007477`*^9, 3.433855477999148*^9}, {
  3.434031915895462*^9, 3.4340319430082617`*^9}, {3.434395688619351*^9, 
  3.4343956886973505`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[TextData[{
 "PowerMod can be used to efficiently look at the leftmost ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 " columns for many rows."
}], "Text",
 CellChangeTimes->{{3.4338556123307476`*^9, 3.4338556368227477`*^9}, {
  3.4338556708775477`*^9, 3.4338556836071477`*^9}}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     RowBox[{"PowerMod", "[", 
      RowBox[{"3", ",", 
       RowBox[{"Range", "[", 
        RowBox[{"0", ",", 
         RowBox[{
          SuperscriptBox["2", "10"], "-", "1"}]}], "]"}], ",", 
       SuperscriptBox["2", "700"]}], "]"}], ",", "2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4338554770007477`*^9, 3.433855477999148*^9}, {
   3.433855684402748*^9, 3.433855768876748*^9}, {3.4340324655770617`*^9, 
   3.4340325034070616`*^9}, {3.4343956639713507`*^9, 3.434395664096151*^9}, 
   3.434395709460951*^9, {3.434395762610151*^9, 3.434395780659351*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Basic properties", "Subsection",
 CellChangeTimes->{{3.4344108789849997`*^9, 3.4344108833842*^9}}],

Cell[TextData[{
 "Each column is periodic.\nThe sequence ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["3", "n"], " ", "mod", " ", 
    SuperscriptBox["2", "a"]}], TraditionalForm]]],
 " is eventually periodic, because eventually we must come back to a state \
that has already visited, at which point it repeats.\nBut in fact it is \
periodic from the start, because we can compute the (unique) predecessor of \
each row by dividing by 3."
}], "Text",
 CellChangeTimes->{{3.4338554865323477`*^9, 3.433855502272748*^9}, {
  3.433855535656748*^9, 3.433855561365548*^9}, {3.433855975810748*^9, 
  3.433855978915148*^9}, {3.433856016901148*^9, 3.433856018804348*^9}, {
  3.4343945512233505`*^9, 3.4343946798609505`*^9}, {3.4344109531317997`*^9, 
  3.4344109681078*^9}}],

Cell["\<\
What if we run the system backward from its initial condition?\
\>", "Text",
 CellChangeTimes->{{3.4338555710843477`*^9, 3.433855588228748*^9}, {
  3.433855823351948*^9, 3.433855831682348*^9}, {3.434394689532951*^9, 
  3.434394714664551*^9}}],

Cell[TextData[{
 "Using ",
 StyleBox["PowerMod", "Input"],
 " naively (with negative exponents) produces something:"
}], "Text",
 CellChangeTimes->{{3.4338555710843477`*^9, 3.433855588228748*^9}, {
  3.433855823351948*^9, 3.433855831682348*^9}, {3.434394689532951*^9, 
  3.434394714664551*^9}}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     RowBox[{"PowerMod", "[", 
      RowBox[{"3", ",", 
       RowBox[{"Range", "[", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["2", "8"]}], ",", 
         RowBox[{
          SuperscriptBox["2", "8"], "-", "1"}]}], "]"}], ",", 
       SuperscriptBox["2", "700"]}], "]"}], ",", "2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4338558022451477`*^9, 3.433855806769148*^9}, {
  3.4340319524618616`*^9, 3.434031952571062*^9}, {3.4340334392666616`*^9, 
  3.4340334394538617`*^9}, {3.434395650882951*^9, 3.4343956510077505`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[TextData[{
 "According to the documentation, ",
 StyleBox["PowerMod", "Input"],
 " is computing powers of the modular inverse of 3 modulo ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", "500"], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.433855864333148*^9, 3.4338559222247477`*^9}, {
  3.434033445428662*^9, 3.4340334455846615`*^9}, {3.434394798888951*^9, 
  3.434394800183751*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "PowerMod"}]], "Input",
 CellChangeTimes->{{3.433855858514348*^9, 3.4338558595439477`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\\!\\(\\*RowBox[{\\\"PowerMod\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"a\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"b\\\", \
\\\"TI\\\"], \\\",\\\", StyleBox[\\\"m\\\", \\\"TI\\\"]}], \\\"]\\\"}]\\) \
gives \\!\\(\\*RowBox[{SuperscriptBox[StyleBox[\\\"a\\\", \\\"TI\\\"], \
StyleBox[\\\"b\\\", \\\"TI\\\"]], \\\" \\\", \\\"mod\\\", \\\" \\\", \
StyleBox[\\\"m\\\", \\\"TI\\\"]}]\\). \\n\\!\\(\\*RowBox[{\\\"PowerMod\\\", \
\\\"[\\\", RowBox[{StyleBox[\\\"a\\\", \\\"TI\\\"], \\\",\\\", \
RowBox[{\\\"-\\\", \\\"1\\\"}], \\\",\\\", StyleBox[\\\"m\\\", \\\"TI\\\"]}], \
\\\"]\\\"}]\\) finds the modular inverse of \\!\\(\\*StyleBox[\\\"a\\\", \
\\\"TI\\\"]\\) modulo \\!\\(\\*StyleBox[\\\"m\\\", \
\\\"TI\\\"]\\).\\n\\!\\(\\*RowBox[{\\\"PowerMod\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"a\\\", \\\"TI\\\"], \\\",\\\", RowBox[{\\\"1\\\", \
\\\"/\\\", StyleBox[\\\"r\\\", \\\"TI\\\"]}], \\\",\\\", StyleBox[\\\"m\\\", \
\\\"TI\\\"]}], \\\"]\\\"}]\\) finds the smallest modular root of \
\\!\\(\\*StyleBox[\\\"a\\\", \\\"TI\\\"]\\).\"\>", "MSG"], " ", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/PowerMod"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.433855859887148*^9},
 CellTags->"Info3433841459-1533185"]
}, Open  ]],

Cell[TextData[{
 "What does this mean?\nIt means that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"PowerMod", "[", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}], ",", 
     SuperscriptBox["2", "a"]}], "]"}], TraditionalForm]]],
 " finds an integer ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0", "\[LessEqual]", "x", "<", 
    SuperscriptBox["2", "a"]}], TraditionalForm]]],
 " such that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"3", "x"}], "\[Congruent]", 
    RowBox[{"1", " ", "mod", " ", 
     SuperscriptBox["2", "a"]}]}], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.433855945234748*^9, 3.433855992611948*^9}, {
  3.4338563454381475`*^9, 3.433856354189748*^9}, {3.434032658065462*^9, 
  3.434032764145462*^9}, {3.4340328076850615`*^9, 3.434032807872262*^9}, {
  3.434032861770262*^9, 3.434032941517462*^9}, {3.4343948673105507`*^9, 
  3.434394868964151*^9}, {3.4344111415954*^9, 3.4344111528118*^9}}],

Cell["For example:", "Text",
 CellChangeTimes->{{3.433855945234748*^9, 3.433855992611948*^9}, {
  3.4338563454381475`*^9, 3.433856354189748*^9}, {3.434032658065462*^9, 
  3.434032764145462*^9}, {3.4340328076850615`*^9, 3.434032807872262*^9}, {
  3.434032861770262*^9, 3.434032941517462*^9}, {3.4343948673105507`*^9, 
  3.434394868964151*^9}, {3.4344111415954*^9, 3.4344111528118*^9}}],

Cell[BoxData[
 RowBox[{"y", "=", 
  RowBox[{"PowerMod", "[", 
   RowBox[{"3", ",", 
    RowBox[{"-", "1"}], ",", 
    SuperscriptBox["2", "50"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.434395000877751*^9, 3.4343950010337505`*^9}, {
  3.434395479938151*^9, 3.434395480047351*^9}}],

Cell[BoxData[
 RowBox[{"BaseForm", "[", 
  RowBox[{
   RowBox[{"3", "y"}], ",", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.4343950081629505`*^9, 3.434395018989351*^9}, {
  3.4343954814825506`*^9, 3.434395481576151*^9}}],

Cell[BoxData[
 RowBox[{"BaseForm", "[", 
  RowBox[{"y", ",", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.434032765814662*^9, 3.434032829041462*^9}, {
  3.4343949864165506`*^9, 3.434395004044551*^9}, {3.4343954831985507`*^9, 
  3.4343954832921505`*^9}}],

Cell[BoxData[
 RowBox[{"y", "\[Equal]", 
  RowBox[{"1", "+", 
   RowBox[{"Total", "[", 
    SuperscriptBox["2", 
     RowBox[{"Range", "[", 
      RowBox[{"1", ",", "50", ",", "2"}], "]"}]], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4340329733102617`*^9, 3.434033053322662*^9}, {
  3.4340332233002615`*^9, 3.434033231053462*^9}, {3.4343954134977508`*^9, 
  3.4343954154789505`*^9}, {3.434395485132951*^9, 3.4343954851797504`*^9}}],

Cell[TextData[{
 "But if we think of ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " going to infinity, these modular inverses look like \"infinite \
integers\"."
}], "Text",
 CellChangeTimes->{{3.433855945234748*^9, 3.433855992611948*^9}, {
   3.4338563454381475`*^9, 3.433856354189748*^9}, {3.434032658065462*^9, 
   3.434032758467062*^9}, 3.434032841147062*^9, {3.434033062776262*^9, 
   3.4340330629478617`*^9}, 3.434033204736262*^9, {3.4344111660094*^9, 
   3.4344111820618*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{"Total", "[", 
   SuperscriptBox["x", 
    RowBox[{"Range", "[", 
     RowBox[{"1", ",", "50", ",", "2"}], "]"}]], "]"}]}]], "Input",
 CellChangeTimes->{{3.4340331740198617`*^9, 3.434033178356662*^9}, {
  3.4340332354526615`*^9, 3.434033237745862*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"i", "=", "0"}], "\[Infinity]"], 
   SuperscriptBox["x", 
    RowBox[{
     RowBox[{"2", " ", "i"}], "+", "1"}]]}]}]], "Input",
 CellChangeTimes->{{3.434033244656662*^9, 3.434033252035462*^9}, {
  3.434033288820262*^9, 3.434033289116662*^9}}],

Cell[BoxData[
 RowBox[{"%", "/.", "\[InvisibleSpace]", 
  RowBox[{"x", "\[Rule]", "2"}]}]], "Input",
 CellChangeTimes->{{3.4340332779470615`*^9, 3.4340332931570616`*^9}}],

Cell["\<\
The power series doesn't converge at 2... yet it gives a very sensible \
answer.\
\>", "Text",
 CellChangeTimes->{{3.4340333128754616`*^9, 3.434033323187062*^9}, {
   3.4340335992758617`*^9, 3.434033601771862*^9}, {3.4340710099020615`*^9, 
   3.434071017608462*^9}, {3.4340717913150616`*^9, 3.434071795012262*^9}, 
   3.434395646530551*^9, 3.4344112691878*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[TextData[{
 "The period length of each column is a power of 2.\nTherefore, at row ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", "n"], TraditionalForm]]],
 " all the periods of the first several of columns will have just ended and \
will be ready to start again.\nThat is, the bits in these columns will be the \
same bits as in row 0."
}], "Text",
 CellChangeTimes->{{3.433855999382348*^9, 3.433856132590748*^9}, {
  3.433856243086548*^9, 3.4338562486089478`*^9}, {3.4338562980453477`*^9, 
  3.4338563096361475`*^9}, {3.4338563678241477`*^9, 3.4338563683701477`*^9}, {
  3.4340336216774616`*^9, 3.434033641271062*^9}, {3.434071842373862*^9, 
  3.434071866241862*^9}, {3.434072038325462*^9, 3.434072046031862*^9}, {
  3.4343284696273775`*^9, 3.4343284717773776`*^9}, {3.4344113654709997`*^9, 
  3.4344113791834*^9}}],

Cell[TextData[{
 "So looking at the binary representations of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["3", 
    SuperscriptBox["2", "n"]], TraditionalForm]]],
 " produces a picture in which the farther down we go, the closer to row 0 we \
get."
}], "Text",
 CellChangeTimes->{{3.433855999382348*^9, 3.433856132590748*^9}, {
  3.433856243086548*^9, 3.4338562486089478`*^9}, {3.4338562980453477`*^9, 
  3.4338563096361475`*^9}, {3.4338563678241477`*^9, 3.4338563683701477`*^9}, {
  3.4340336216774616`*^9, 3.434033641271062*^9}, {3.434071842373862*^9, 
  3.434071866241862*^9}, {3.434072038325462*^9, 3.434072046031862*^9}, {
  3.4343284696273775`*^9, 3.4343284717773776`*^9}, {3.4344113889646*^9, 
  3.4344114033322*^9}}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     RowBox[{"PowerMod", "[", 
      RowBox[{"3", ",", 
       SuperscriptBox["2", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "255"}], "]"}]], ",", 
       SuperscriptBox["2", "700"]}], "]"}], ",", "2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.434033645217862*^9, 3.434033652191062*^9}, {
  3.434395631694951*^9, 3.434395631835351*^9}}],

Cell["\<\
Two observations:
\[Bullet] In this case, each column (except the leftmost column) eventually \
becomes white.
\[Bullet] There is some other structure here \[LongDash] diagonal lines above \
the white triangular region.\
\>", "Text",
 CellChangeTimes->{{3.433855999382348*^9, 3.433856132590748*^9}, {
  3.433856243086548*^9, 3.4338562486089478`*^9}, {3.4338562980453477`*^9, 
  3.4338563096361475`*^9}, {3.4338563678241477`*^9, 3.4338563683701477`*^9}, {
  3.4340336216774616`*^9, 3.434033667385462*^9}, {3.434033852495062*^9, 
  3.434033858984662*^9}, {3.434033889326662*^9, 3.4340339055974617`*^9}, {
  3.4343284787763777`*^9, 3.4343284849413776`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Colunns", "Subsection",
 CellChangeTimes->{{3.434328551130378*^9, 3.4343285592703776`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     RowBox[{"PowerMod", "[", 
      RowBox[{"3", ",", 
       SuperscriptBox["2", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "255"}], "]"}]], ",", 
       SuperscriptBox["2", "700"]}], "]"}], ",", "2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.434033645217862*^9, 3.434033652191062*^9}, {
  3.434366278224145*^9, 3.434366278738945*^9}}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzstc21NVnTa/Xy4wiW4AMmMAZtHMQoTIDeHXzcfFRV2qqpyNTuzIZOKLRi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   "], {{0, 0}, {700, 256}}, {0, 1}],
  Frame->Automatic,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}}]], "Output",
 CellChangeTimes->{3.434366284604545*^9}]
}, Open  ]],

Cell["Each column eventually becomes white.", "Text",
 CellChangeTimes->{{3.434033928170662*^9, 3.4340339357210617`*^9}}],

Cell[TextData[{
 "Another way to say this is that in some sense the binary representations of \
",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["3", 
    SuperscriptBox["2", "n"]], TraditionalForm]]],
 " are \"converging\" bitwise to the row {1, 0, 0, 0, 0, 0, \
\[CenterEllipsis]} representing 1 in binary."
}], "Text",
 CellChangeTimes->{{3.4338563754837475`*^9, 3.4338563964501476`*^9}, {
  3.4338564301305475`*^9, 3.433856440286148*^9}, {3.433856596816548*^9, 
  3.4338566176425476`*^9}, {3.434039329827862*^9, 3.4340393484854617`*^9}}],

Cell[TextData[{
 "We can prove this using Euler's theorem from number theory:\nIf ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]]],
 " is coprime to ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]]],
 " then ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"PowerMod", "[", 
     RowBox[{"k", ",", 
      RowBox[{"EulerPhi", "[", "m", "]"}], ",", "m"}], "]"}], "\[Equal]", 
    "1"}], TraditionalForm]]],
 ", or ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{"\[Phi]", "(", "m", ")"}]], "\[Congruent]", 
    RowBox[{"1", "  ", "mod", " ", "m"}]}], TraditionalForm]]],
 ".\nIn our case, letting ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "=", "3"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", "=", 
    SuperscriptBox["2", 
     RowBox[{"n", "+", "1"}]]}], TraditionalForm]]],
 " gives ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["3", 
     SuperscriptBox["2", "n"]], "\[Congruent]", 
    RowBox[{"1", " ", "mod", " ", 
     SuperscriptBox["2", 
      RowBox[{"n", "+", "1"}]]}]}], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.4338563754837475`*^9, 3.4338563964501476`*^9}, {
  3.4338564301305475`*^9, 3.433856440286148*^9}, {3.433856596816548*^9, 
  3.4338566176425476`*^9}, {3.434039329827862*^9, 3.4340393484854617`*^9}}],

Cell[TextData[{
 "So ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["3", 
     SuperscriptBox["2", "n"]], "\[Rule]", "1"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "."
}], "Text",
 CellChangeTimes->{{3.433856620575348*^9, 3.433856652368148*^9}, {
  3.4344115319386*^9, 3.4344115786762*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Diagonal stripes", "Subsection",
 CellChangeTimes->{{3.4343285058623776`*^9, 3.4343285110163774`*^9}, {
  3.434411597755*^9, 3.4344116022634*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     RowBox[{"PowerMod", "[", 
      RowBox[{"3", ",", 
       SuperscriptBox["2", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "255"}], "]"}]], ",", 
       SuperscriptBox["2", "700"]}], "]"}], ",", "2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.434033645217862*^9, 3.434033652191062*^9}, {
  3.4343662871473455`*^9, 3.434366287318945*^9}}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzstc21NVnTa/Xy4wiW4AMmMAZtHMQoTIDeHXzcfFRV2qqpyNTuzIZOKLRi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   "], {{0, 0}, {700, 256}}, {0, 1}],
  Frame->Automatic,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}}]], "Output",
 CellChangeTimes->{3.4343662900489454`*^9}]
}, Open  ]],

Cell["\<\
Let's subtract 1 from each integer (to make the rightmost column white) and \
shear the image to make these lines vertical:\
\>", "Text",
 CellChangeTimes->{{3.433856672757348*^9, 3.4338566860329475`*^9}, {
  3.4339871504939146`*^9, 3.4339871518198805`*^9}}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Reverse", "[", 
     RowBox[{"IntegerDigits", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"PowerMod", "[", 
          RowBox[{"3", ",", 
           SuperscriptBox["2", "n"], ",", 
           SuperscriptBox["2", 
            RowBox[{"700", "+", "n"}]]}], "]"}], "-", "1"}], 
        SuperscriptBox["2", "n"]], ",", "2", ",", "700"}], "]"}], "]"}], ",", 
    
    RowBox[{"{", 
     RowBox[{"n", ",", "0", ",", "255"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.433856282164548*^9, 3.4338562832409477`*^9}, {
  3.433856875198548*^9, 3.433856875307748*^9}, {3.433857283138548*^9, 
  3.4338572980053477`*^9}, {3.434032013192662*^9, 3.4340320134422617`*^9}, {
  3.4343663102821455`*^9, 3.4343663126845455`*^9}}],

Cell[TextData[{
 "These (shifted) rows are converging bitwise to something too \[LongDash] \
the row ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
    "0", ",", " ", "0", ",", "1", ",", "0", ",", "1", ",", "1", ",", "1", ",",
      "1", ",", "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "1", ",", 
     "1", ",", "1", ",", "0", ",", "1", ",", "0", ",", "0", ",", "1", ",", 
     "0", ",", "0", ",", "1", ",", "\[CenterEllipsis]"}], "}"}], 
   TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.433856557488948*^9, 3.4338565771917477`*^9}, {
  3.4338569001117477`*^9, 3.4338569006577477`*^9}}],

Cell["\<\
In this picture we also observe some new subtle diagonal structures that we \
couldn't see well before.
Subtracting the limit again and shearing makes these features clear.\
\>", "Text",
 CellChangeTimes->{{3.4338567433473477`*^9, 3.433856748230148*^9}, {
  3.434034045030262*^9, 3.434034045404662*^9}, {3.434326956576378*^9, 
  3.4343269579813776`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Secondary stripes", "Subsection",
 CellChangeTimes->{{3.4344116591722*^9, 3.4344116627446003`*^9}}],

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"c1", "=", 
     RowBox[{"Mod", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"PowerMod", "[", 
          RowBox[{"3", ",", 
           SuperscriptBox["2", "511"], ",", 
           SuperscriptBox["2", "1023"]}], "]"}], "-", "1"}], 
        SuperscriptBox["2", "511"]], ",", 
       SuperscriptBox["2", "511"]}], "]"}]}], "}"}], ",", 
   RowBox[{"ArrayPlot", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Reverse", "[", 
       RowBox[{"IntegerDigits", "[", 
        RowBox[{
         FractionBox[
          RowBox[{
           FractionBox[
            RowBox[{
             RowBox[{"PowerMod", "[", 
              RowBox[{"3", ",", 
               SuperscriptBox["2", "n"], ",", 
               SuperscriptBox["2", 
                RowBox[{"1023", "+", "n"}]]}], "]"}], "-", "1"}], 
            SuperscriptBox["2", "n"]], "-", "c1"}], 
          SuperscriptBox["2", "n"]], ",", "2", ",", "511"}], "]"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "0", ",", "255"}], "}"}]}], "]"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.433857083115348*^9, 3.4338571508817477`*^9}, {
  3.433857185217348*^9, 3.4338572713761477`*^9}, {3.4338573063357477`*^9, 
  3.4338573294393477`*^9}, {3.4338939943383756`*^9, 3.4338939972555757`*^9}, {
  3.434032019432662*^9, 3.4340320196666617`*^9}}],

Cell["\<\
Again we see new diagonal structures.
Maybe if we continue to iterate this subtract-and-shear operation we will \
continue to find convergent sequences of rows...\
\>", "Text",
 CellChangeTimes->{{3.4338567433473477`*^9, 3.433856785451748*^9}, {
  3.4338942541875753`*^9, 3.4338942543123755`*^9}, {3.4343286205063777`*^9, 
  3.4343286306483774`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"max", "=", "500"}], ",", 
     RowBox[{"c0", "=", "1"}], ",", "c1", ",", "c2"}], "}"}], ",", 
   RowBox[{
    RowBox[{"c1", "=", 
     FractionBox[
      RowBox[{
       RowBox[{"PowerMod", "[", 
        RowBox[{"3", ",", 
         SuperscriptBox["2", 
          RowBox[{"4", " ", "max"}]], ",", 
         SuperscriptBox["2", 
          RowBox[{"8", " ", "max"}]]}], "]"}], "-", "1"}], 
      SuperscriptBox["2", 
       RowBox[{"4", " ", "max"}]]]}], ";", 
    RowBox[{"c2", "=", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"PowerMod", "[", 
          RowBox[{"3", ",", 
           SuperscriptBox["2", 
            RowBox[{"2", " ", "max"}]], ",", 
           SuperscriptBox["2", 
            RowBox[{"8", " ", "max"}]]}], "]"}], "-", "1"}], 
        SuperscriptBox["2", 
         RowBox[{"2", " ", "max"}]]], "-", "c1"}], 
      SuperscriptBox["2", 
       RowBox[{"2", " ", "max"}]]]}], ";", 
    RowBox[{"ArrayPlot", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Reverse", "[", 
        RowBox[{"IntegerDigits", "[", 
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox[
             RowBox[{
              FractionBox[
               RowBox[{
                RowBox[{"PowerMod", "[", 
                 RowBox[{"3", ",", 
                  SuperscriptBox["2", "n"], ",", 
                  SuperscriptBox["2", 
                   RowBox[{"8", " ", "max"}]]}], "]"}], "-", "c0"}], 
               SuperscriptBox["2", "n"]], "-", "c1"}], 
             SuperscriptBox["2", "n"]], "-", "c2"}], 
           SuperscriptBox["2", "n"]], ",", "2", ",", "max"}], "]"}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "max"}], "}"}]}], "]"}], "]"}]}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.4258660158275633`*^9, 3.4258660232531633`*^9}, {
  3.4258660675571632`*^9, 3.425866134559163*^9}, {3.425866166866763*^9, 
  3.4258661774279633`*^9}, {3.425866566273563*^9, 3.425866579502363*^9}, {
  3.425866661792363*^9, 3.425866689544763*^9}, {3.4258667520539627`*^9, 
  3.4258667663591633`*^9}, {3.4258667988851633`*^9, 3.4258667990255632`*^9}, {
  3.425867199103163*^9, 3.425867216887163*^9}, {3.4258672489139633`*^9, 
  3.425867321344763*^9}, {3.425867466674363*^9, 3.425867514332363*^9}, {
  3.4258675634567633`*^9, 3.425867648273963*^9}, {3.425867695713563*^9, 
  3.425867732903963*^9}, {3.425867806473563*^9, 3.4258678321667633`*^9}, {
  3.425868115166363*^9, 3.425868279668363*^9}, {3.425868936351363*^9, 
  3.425868943059363*^9}, {3.425869031620563*^9, 3.4258692911421633`*^9}, {
  3.4338942130191755`*^9, 3.4338942167631755`*^9}, {3.433894279334776*^9, 
  3.4338943153863754`*^9}, {3.434032039244662*^9, 3.434032039572262*^9}}],

Cell[TextData[{
 "So what is this hidden structure?\nWhy is it that, despite the apparent \
complexity in bits of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["3", 
    SuperscriptBox["2", "n"]], TraditionalForm]]],
 ", every region can be decomposed into a sum of simple periodic regions?"
}], "Text",
 CellChangeTimes->{{3.4338567433473477`*^9, 3.433856809834548*^9}, {
  3.4343286452043777`*^9, 3.4343286453933773`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Convergence", "Subsection",
 CellChangeTimes->{{3.4343286806173773`*^9, 3.434328681793378*^9}}],

Cell["Let's examine this convergence more closely.", "Text",
 CellChangeTimes->{{3.433856816308548*^9, 3.433856867320548*^9}, {
  3.4338569112813478`*^9, 3.433856931920148*^9}, {3.4338569842737474`*^9, 
  3.433856995022148*^9}, {3.4338942694911757`*^9, 3.4338942730635757`*^9}, {
  3.433894339503976*^9, 3.4338943770999756`*^9}, {3.4340341076486616`*^9, 
  3.434034114247462*^9}, {3.434076269094262*^9, 3.4340762707010617`*^9}, {
  3.4344116952706003`*^9, 3.434411743459*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["3", 
     SuperscriptBox["2", "n"]], "\[Rule]", "1"}], TraditionalForm]]],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["3", 
       SuperscriptBox["2", "n"]], "-", "1"}], 
     SuperscriptBox["2", "n"]], "\[Rule]", 
    SubscriptBox["c", "1"]}], TraditionalForm]]],
 ", where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "1"], TraditionalForm]]],
 " is some \"infinite integer\"\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["3", 
         SuperscriptBox["2", "n"]], "-", "1"}], 
       SuperscriptBox["2", "n"]], "-", 
      SubscriptBox["c", "1"]}], 
     SuperscriptBox["2", "n"]], "\[Rule]", 
    SubscriptBox["c", "2"]}], TraditionalForm]]],
 " is some other infinite integer\netc."
}], "Text",
 CellChangeTimes->{{3.433856816308548*^9, 3.433856867320548*^9}, {
  3.4338569112813478`*^9, 3.433856931920148*^9}, {3.4338569842737474`*^9, 
  3.433856995022148*^9}, {3.4338942694911757`*^9, 3.4338942730635757`*^9}, {
  3.433894339503976*^9, 3.4338943770999756`*^9}, {3.4340341076486616`*^9, 
  3.434034114247462*^9}, {3.434076269094262*^9, 3.4340762707010617`*^9}, {
  3.4344116952706003`*^9, 3.434411759605*^9}}],

Cell[BoxData[
 RowBox[{"Fold", "[", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"#1", "-", "#2"}], 
     SuperscriptBox["2", "n"]], "&"}], ",", 
   SuperscriptBox["3", 
    SuperscriptBox["2", "n"]], ",", 
   RowBox[{"Thread", "[", 
    SubscriptBox["c", 
     RowBox[{"Range", "[", 
      RowBox[{"0", ",", "4"}], "]"}]], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4338944728995757`*^9, 3.4338945347691755`*^9}, 
   3.4338945744867754`*^9}],

Cell["Let's \"unravel\" these expressions.", "Text",
 CellChangeTimes->{{3.4338943920135756`*^9, 3.4338944040723753`*^9}, {
  3.4340341241378617`*^9, 3.4340341264934616`*^9}}],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"%", "/.", "\[InvisibleSpace]", 
      RowBox[{
       SuperscriptBox["3", 
        SuperscriptBox["2", "n"]], "\[Rule]", 
       RowBox[{"f", "[", "n", "]"}]}]}], ")"}], "\[Equal]", "something"}], 
   ",", 
   RowBox[{"f", "[", "n", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4338944071455755`*^9, 3.4338944557551756`*^9}, {
  3.4338945408843756`*^9, 3.4338945790731754`*^9}, {3.4344118391806*^9, 
  3.4344118407406*^9}, {3.4344119307838*^9, 3.4344119398006*^9}}],

Cell[TextData[{
 "Replace ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", "n"], TraditionalForm]]],
 " with ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 ":"
}], "Text",
 CellChangeTimes->{{3.433894992717922*^9, 3.433895008083922*^9}}],

Cell[BoxData[
 RowBox[{"%", "/.", "\[InvisibleSpace]", 
  RowBox[{"n", "\[Rule]", 
   RowBox[{"Log", "[", 
    RowBox[{"2", ",", "x"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4338945920679755`*^9, 3.4338946172619753`*^9}, {
  3.433895015244322*^9, 3.433895019487522*^9}}],

Cell[TextData[{
 "So this is some sort of power series for ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["3", "x"], TraditionalForm]]],
 ".\nOf course, we know a power series for ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["3", "x"], TraditionalForm]]],
 ":"
}], "Text",
 CellChangeTimes->{{3.433895609791522*^9, 3.433895631662722*^9}, {
  3.4344118692106*^9, 3.4344118694446*^9}}],

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   SuperscriptBox["3", "x"], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4338956321775217`*^9, 3.433895641334722*^9}}],

Cell[TextData[{
 "So if this guess is correct, then ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "i"], TraditionalForm]]],
 " should be ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"Log", "[", "3", "]"}], "i"], "/", 
    RowBox[{"i", "!"}]}], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.433895730941122*^9, 3.433895777491522*^9}, 
   3.4340312575286617`*^9, 3.4344118172314*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"i", "\[Equal]", "0"}], TraditionalForm]]],
 ":\nWorks!"
}], "Text",
 CellChangeTimes->{{3.433895730941122*^9, 3.433895777491522*^9}, 
   3.4340312575286617`*^9, {3.4344120046809998`*^9, 3.4344120533218*^9}}],

Cell[BoxData[
 FractionBox[
  SuperscriptBox[
   RowBox[{"Log", "[", "3", "]"}], "0"], 
  RowBox[{"0", "!"}]]], "Input",
 CellChangeTimes->{{3.4344120129646*^9, 3.4344120176289997`*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"i", "\[Equal]", "1"}], TraditionalForm]]],
 ":\nDoesn't work..."
}], "Text",
 CellChangeTimes->{{3.4344120417153997`*^9, 3.4344120496870003`*^9}}],

Cell[BoxData[{
 RowBox[{"RealDigits", "[", 
  RowBox[{
   RowBox[{"Log", "[", "3", "]"}], ",", "2", ",", "40"}], "]"}], "\n", 
 RowBox[{"Reverse", "[", 
  RowBox[{"IntegerDigits", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"PowerMod", "[", 
       RowBox[{"3", ",", 
        SuperscriptBox["2", "255"], ",", 
        SuperscriptBox["2", "511"]}], "]"}], "-", "1"}], 
     SuperscriptBox["2", "255"]], ",", "2", ",", "40"}], "]"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.4339860391925287`*^9, 3.4339861151932926`*^9}, {
  3.433986209585867*^9, 3.4339862106622324`*^9}, {3.433986249614184*^9, 
  3.433986253670054*^9}}],

Cell["So we must have the wrong \"Log[3]\".", "Text",
 CellChangeTimes->{{3.433986536212866*^9, 3.433986542421507*^9}, {
  3.433986749069408*^9, 3.433986757898782*^9}, {3.433986888264639*^9, 
  3.433986927638029*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Direction of convergence", "Subsection",
 CellChangeTimes->{{3.434412186751*^9, 3.4344121898866*^9}}],

Cell[TextData[{
 "Convergence of real numbers fills in ",
 StyleBox["higher",
  FontSlant->"Italic"],
 " indices first:"
}], "Text",
 CellChangeTimes->{{3.4344122131462*^9, 3.4344122266401997`*^9}}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"First", "[", 
     RowBox[{"RealDigits", "[", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          FractionBox["1", "n"]}], ")"}], "n"], ",", "2", ",", "700", ",", 
       "1"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "255"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4344123217377996`*^9, 3.4344124237774*^9}, {
  3.4344124777066*^9, 3.434412541807*^9}}],

Cell[TextData[{
 "Our power series fills in bits of ",
 StyleBox["lower",
  FontSlant->"Italic"],
 " indices first:"
}], "Text",
 CellChangeTimes->{{3.43398657699022*^9, 3.4339866746125174`*^9}, {
  3.433986852650752*^9, 3.4339868826175833`*^9}, {3.434241952076*^9, 
  3.434241953086*^9}, {3.434327185090378*^9, 3.434327186562378*^9}, {
  3.4344121996521997`*^9, 3.4344122115081997`*^9}}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     RowBox[{"PowerMod", "[", 
      RowBox[{"3", ",", 
       SuperscriptBox["2", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "255"}], "]"}]], ",", 
       SuperscriptBox["2", "700"]}], "]"}], ",", "2"}], "]"}]}], 
  "]"}]], "Input"],

Cell[TextData[{
 "So in our power series the low indices of the result are somehow ",
 StyleBox["stronger",
  FontSlant->"Italic"],
 " than the higher indices."
}], "Text",
 CellChangeTimes->{{3.43398657699022*^9, 3.4339866746125174`*^9}, {
  3.433986852650752*^9, 3.4339868826175833`*^9}, {3.434241952076*^9, 
  3.434241953086*^9}, {3.434327185090378*^9, 3.434327186562378*^9}, {
  3.4344121996521997`*^9, 3.434412236125*^9}}],

Cell["\<\
Therefore the \"tail\" (small region) of numbers is backward from the normal \
sense:
Now two numbers are close together if their difference is divisible by a \
large power of 2.\
\>", "Text",
 CellChangeTimes->{{3.43398657699022*^9, 3.4339866746125174`*^9}, {
  3.433986852650752*^9, 3.4339868826175833`*^9}, {3.434241952076*^9, 
  3.434241953086*^9}, {3.434327185090378*^9, 3.434327188779378*^9}, {
  3.4344122415538*^9, 3.4344122830341997`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Paranormal phenomena", "Subsubsection",
 CellChangeTimes->{{3.4344121200741997`*^9, 3.4344121748638*^9}}],

Cell["Several mysteries:", "Text",
 CellChangeTimes->{{3.4340331292010617`*^9, 3.434033131353862*^9}, {
  3.4344121129294*^9, 3.4344121150354*^9}}],

Cell[TextData[{
 "\[Bullet] 1/3 corresponds to the divergent series ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "+", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], "\[Infinity]"], 
     SuperscriptBox["2", 
      RowBox[{
       RowBox[{"2", " ", "i"}], "+", "1"}]]}]}], TraditionalForm]]],
 ".\n\[Bullet] ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["3", 
     SuperscriptBox["2", "n"]], "\[Rule]", "1"}], TraditionalForm]]],
 " as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "\[Rule]", "\[Infinity]"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ".\n\[Bullet] \"Log[3]\" is not Log[3].\n\[Bullet] Two numbers are close if \
their difference is highly divisible by 2."
}], "Text",
 CellChangeTimes->{{3.433986536212866*^9, 3.433986542421507*^9}, {
  3.433986749069408*^9, 3.433986757898782*^9}, {3.433986888264639*^9, 
  3.4339870079915686`*^9}, {3.4340331414626617`*^9, 3.4340331868274617`*^9}, {
  3.434033476457062*^9, 3.434033531759062*^9}, {3.4340342910890617`*^9, 
  3.434034292695862*^9}, {3.434241955844*^9, 3.4342419611619997`*^9}, {
  3.434328048102378*^9, 3.4343280484813776`*^9}, {3.4344126088402*^9, 
  3.4344126288394003`*^9}}],

Cell[TextData[{
 "We must conclude from all this that in some sense ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", "i"], TraditionalForm]]],
 " gets ",
 StyleBox["small",
  FontSlant->"Italic"],
 " as ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]]],
 " gets large."
}], "Text",
 CellChangeTimes->{{3.433986680056778*^9, 3.433986728665131*^9}, {
   3.433986818222435*^9, 3.433986851449583*^9}, 3.4339868923205347`*^9, 
   3.433986975388405*^9, {3.4339872828565207`*^9, 3.433987315303689*^9}, {
   3.433988234376943*^9, 3.433988236420504*^9}, {3.4339883116422577`*^9, 
   3.4339885145795717`*^9}, {3.4339886823242216`*^9, 3.433988708251089*^9}, {
   3.434034306611062*^9, 3.4340343178274617`*^9}, {3.4344126543454*^9, 
   3.434412655453*^9}}],

Cell["Let's define a new \"absolute value\" that captures this.", "Text",
 CellChangeTimes->{{3.433986680056778*^9, 3.433986728665131*^9}, {
   3.433986818222435*^9, 3.433986851449583*^9}, 3.4339868923205347`*^9, 
   3.433986975388405*^9, {3.4339872828565207`*^9, 3.433987315303689*^9}, {
   3.433988234376943*^9, 3.433988236420504*^9}, {3.4339883116422577`*^9, 
   3.4339885145795717`*^9}, {3.4339886823242216`*^9, 3.433988708251089*^9}, {
   3.434034306611062*^9, 3.4340343178274617`*^9}, {3.4344126543454*^9, 
   3.434412655453*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["2-adic numbers", "Section",
 CellChangeTimes->{{3.434034801757062*^9, 3.434034803270262*^9}}],

Cell[TextData[{
 "Every rational number ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "\[NotEqual]", "0"}], TraditionalForm]]],
 " has a representation ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "\[Equal]", 
    RowBox[{
     SuperscriptBox["2", "\[Alpha]"], 
     FractionBox["n", "d"]}]}], TraditionalForm]]],
 " for some integer ",
 Cell[BoxData[
  FormBox["\[Alpha]", TraditionalForm]]],
 ", where ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["d", TraditionalForm]]],
 " are not divisible by 2.  Moreover, ",
 Cell[BoxData[
  FormBox["\[Alpha]", TraditionalForm]]],
 " is unique."
}], "Text",
 CellChangeTimes->{{3.433986680056778*^9, 3.433986728665131*^9}, {
   3.433986818222435*^9, 3.433986851449583*^9}, 3.4339868923205347`*^9, 
   3.433986975388405*^9, {3.4339872828565207`*^9, 3.433987315303689*^9}, {
   3.433988234376943*^9, 3.433988236420504*^9}, {3.4339883116422577`*^9, 
   3.4339885145795717`*^9}, {3.4339886823242216`*^9, 3.433988708251089*^9}, {
   3.434034306611062*^9, 3.4340343319454618`*^9}, {3.434328713411378*^9, 
   3.4343287413343773`*^9}}],

Cell[TextData[{
 "We want ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    RowBox[{"\[LeftBracketingBar]", "r", "\[RightBracketingBar]"}], "2"], 
   TraditionalForm]]],
 " to be large when ",
 Cell[BoxData[
  FormBox["\[Alpha]", TraditionalForm]]],
 " is small and small (but positive) when ",
 Cell[BoxData[
  FormBox["\[Alpha]", TraditionalForm]]],
 " is large.\nA natural choice is to let ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     RowBox[{"\[LeftBracketingBar]", "r", "\[RightBracketingBar]"}], "2"], ":=",
     
    SuperscriptBox["2", 
     RowBox[{"-", "\[Alpha]"}]]}], TraditionalForm]]],
 "; this is called the 2-adic norm of ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]]],
 ".\nSince 0 is very highly divisible by 2, let us define ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     RowBox[{"\[LeftBracketingBar]", "0", "\[RightBracketingBar]"}], "2"], 
    "=", "0"}], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.433986680056778*^9, 3.433986728665131*^9}, {
   3.433986818222435*^9, 3.433986851449583*^9}, 3.4339868923205347`*^9, 
   3.433986975388405*^9, {3.4339872828565207`*^9, 3.433987315303689*^9}, {
   3.433988234376943*^9, 3.433988236420504*^9}, {3.4339883116422577`*^9, 
   3.4339885145795717`*^9}, {3.4339886823242216`*^9, 3.433988708251089*^9}, {
   3.434034306611062*^9, 3.4340343319454618`*^9}, {3.434328713411378*^9, 
   3.4343287413343773`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TwoAdicNorm", "[", 
   RowBox[{"r", ":", 
    RowBox[{"_Integer", "|", "_Rational"}]}], "]"}], ":=", 
  SuperscriptBox["2", 
   RowBox[{"-", 
    RowBox[{"Subtract", "@@", 
     RowBox[{"IntegerExponent", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Numerator", "[", "r", "]"}], ",", 
         RowBox[{"Denominator", "[", "r", "]"}]}], "}"}], ",", "2"}], 
      "]"}]}]}]]}]], "Input",
 CellChangeTimes->{{3.4344127439518003`*^9, 3.434412823543*^9}}],

Cell[BoxData[
 RowBox[{"TwoAdicNorm", "[", "16", "]"}]], "Input",
 CellChangeTimes->{{3.4344129072994003`*^9, 3.4344129172209997`*^9}}],

Cell[BoxData[
 RowBox[{"TwoAdicNorm", "[", "28", "]"}]], "Input",
 CellChangeTimes->{{3.4344127968982*^9, 3.4344127978185997`*^9}, {
  3.4344129529918003`*^9, 3.434412953101*^9}}],

Cell[BoxData[
 RowBox[{"TwoAdicNorm", "[", "0", "]"}]], "Input",
 CellChangeTimes->{{3.4344129211678*^9, 3.4344129237574*^9}}],

Cell[TextData[{
 "Then, naturally, we write ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"b", "(", "n", ")"}], "\[Rule]", "l"}], TraditionalForm]]],
 " if the sequence of 2-adic norms ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     RowBox[{"\[LeftBracketingBar]", 
      RowBox[{
       RowBox[{"b", "(", "n", ")"}], "-", "l"}], "\[RightBracketingBar]"}], 
     "2"], "\[Rule]", "0"}], TraditionalForm]]],
 " as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "\[Rule]", "\[Infinity]"}], TraditionalForm]]],
 ".  So ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["3", 
     SuperscriptBox["2", "n"]], "\[Rule]", "1"}], TraditionalForm]]],
 " after all."
}], "Text",
 CellChangeTimes->{{3.433988585792659*^9, 3.433988649346244*^9}, {
  3.433988693212882*^9, 3.433988700981582*^9}, {3.4339887468917933`*^9, 
  3.433988752164526*^9}, {3.4340293067884617`*^9, 3.4340293578628616`*^9}, {
  3.434034351710662*^9, 3.4340343601970615`*^9}, {3.4340345390988617`*^9, 
  3.434034539254862*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[TextData[{
 "The 2-adic norm induces a metric on the rational numbers.\nIn particular, \
it satisfies the triangle inequality ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox[
      RowBox[{"\[LeftBracketingBar]", 
       RowBox[{"x", "-", "y"}], "\[RightBracketingBar]"}], "2"], "+", 
     SubscriptBox[
      RowBox[{"\[LeftBracketingBar]", 
       RowBox[{"y", "-", "z"}], "\[RightBracketingBar]"}], "2"]}], 
    "\[GreaterEqual]", 
    SubscriptBox[
     RowBox[{"\[LeftBracketingBar]", 
      RowBox[{"x", "-", "z"}], "\[RightBracketingBar]"}], "2"]}], 
   TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.433988585792659*^9, 3.433988649346244*^9}, {
   3.433988693212882*^9, 3.433988700981582*^9}, {3.4339887468917933`*^9, 
   3.433988752164526*^9}, {3.4340293067884617`*^9, 3.4340293578628616`*^9}, {
   3.434034351710662*^9, 3.434034407480662*^9}, {3.434034451302062*^9, 
   3.434034547585262*^9}, {3.4340345971318617`*^9, 3.434034597475062*^9}, 
   3.434037833131662*^9, {3.4343287488053775`*^9, 3.4343287490413775`*^9}, {
   3.4344129782326*^9, 3.4344129820078*^9}}],

Cell[TextData[{
 "There are some strange properties of this metric, however.\nFor one, every \
triangle is isosceles:\n\tIf ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     RowBox[{"\[LeftBracketingBar]", 
      RowBox[{"x", "-", "y"}], "\[RightBracketingBar]"}], "2"], "\[Equal]", 
    SubscriptBox[
     RowBox[{"\[LeftBracketingBar]", 
      RowBox[{"y", "-", "z"}], "\[RightBracketingBar]"}], "2"]}], 
   TraditionalForm]]],
 ", then the triangle is isosceles.\n\tIf ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     RowBox[{"\[LeftBracketingBar]", 
      RowBox[{"x", "-", "y"}], "\[RightBracketingBar]"}], "2"], "\[NotEqual]",
     
    SubscriptBox[
     RowBox[{"\[LeftBracketingBar]", 
      RowBox[{"y", "-", "z"}], "\[RightBracketingBar]"}], "2"]}], 
   TraditionalForm]]],
 ", then ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     RowBox[{"\[LeftBracketingBar]", 
      RowBox[{"x", "-", "z"}], "\[RightBracketingBar]"}], "2"], "\[Equal]", 
    RowBox[{"max", "(", 
     RowBox[{
      SubscriptBox[
       RowBox[{"\[LeftBracketingBar]", 
        RowBox[{"x", "-", "y"}], "\[RightBracketingBar]"}], "2"], ",", 
      SubscriptBox[
       RowBox[{"\[LeftBracketingBar]", 
        RowBox[{"y", "-", "z"}], "\[RightBracketingBar]"}], "2"]}], ")"}]}], 
   TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.433988585792659*^9, 3.433988649346244*^9}, {
  3.433988693212882*^9, 3.433988700981582*^9}, {3.4339887468917933`*^9, 
  3.433988752164526*^9}, {3.4340293067884617`*^9, 3.4340293578628616`*^9}, {
  3.434034351710662*^9, 3.434034407480662*^9}, {3.434034451302062*^9, 
  3.434034547585262*^9}, {3.4340345971318617`*^9, 3.434034597475062*^9}, {
  3.434037833131662*^9, 3.434037881351262*^9}, {3.434037996962862*^9, 
  3.4340380662112617`*^9}, {3.434038097504862*^9, 3.4340381307328615`*^9}}],

Cell[BoxData[
 RowBox[{"20", "+", "4"}]], "Input",
 CellChangeTimes->{{3.4343960111181507`*^9, 3.434396012256951*^9}}],

Cell[BoxData[
 RowBox[{"20", "+", "2"}]], "Input",
 CellChangeTimes->{{3.434396029463751*^9, 3.434396034408951*^9}}],

Cell["\<\
The real numbers are constructed by taking limits of rational numbers (in the \
real norm).
Taking limits of rational numbers in the 2-adic norm produces a different \
\"completion\" of the rationals.  This is called the set of 2-adic numbers.\
\>", "Text",
 CellChangeTimes->{{3.4340293653508615`*^9, 3.434029445378862*^9}, {
  3.434038198826862*^9, 3.434038204474062*^9}, {3.434412692113*^9, 
  3.4344127334997997`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["\<\
So perhaps our power series must be interpreted as a 2-adic power series, not \
as a real power series.\
\>", "Text",
 CellChangeTimes->{{3.4339888089945974`*^9, 3.4339888200704556`*^9}, {
   3.4340294639896617`*^9, 3.434029465658862*^9}, {3.434034737204262*^9, 
   3.434034760869462*^9}, {3.4340348421142616`*^9, 3.4340348570902615`*^9}, 
   3.434243205875*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   SuperscriptBox["3", "x"], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4338956321775217`*^9, 3.433895641334722*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "+", 
   RowBox[{
    RowBox[{"Log", "[", "3", "]"}], " ", "x"}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     RowBox[{"Log", "[", "3", "]"}], "2"], " ", 
    SuperscriptBox["x", "2"]}], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    SuperscriptBox[
     RowBox[{"Log", "[", "3", "]"}], "3"], " ", 
    SuperscriptBox["x", "3"]}], "+", 
   RowBox[{
    FractionBox["1", "24"], " ", 
    SuperscriptBox[
     RowBox[{"Log", "[", "3", "]"}], "4"], " ", 
    SuperscriptBox["x", "4"]}], "+", 
   RowBox[{
    FractionBox["1", "120"], " ", 
    SuperscriptBox[
     RowBox[{"Log", "[", "3", "]"}], "5"], " ", 
    SuperscriptBox["x", "5"]}], "+", 
   RowBox[{
    FractionBox["1", "720"], " ", 
    SuperscriptBox[
     RowBox[{"Log", "[", "3", "]"}], "6"], " ", 
    SuperscriptBox["x", "6"]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"Log", "[", "3", "]"}], "7"], " ", 
     SuperscriptBox["x", "7"]}], "5040"], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"Log", "[", "3", "]"}], "8"], " ", 
     SuperscriptBox["x", "8"]}], "40320"], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"Log", "[", "3", "]"}], "9"], " ", 
     SuperscriptBox["x", "9"]}], "362880"], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"Log", "[", "3", "]"}], "10"], " ", 
     SuperscriptBox["x", "10"]}], "3628800"], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "x", "]"}], "11"],
    SeriesData[$CellContext`x, 0, {}, 0, 11, 1],
    Editable->False]}],
  SeriesData[$CellContext`x, 0, {1, 
    Log[3], Rational[1, 2] Log[3]^2, Rational[1, 6] Log[3]^3, Rational[1, 24] 
    Log[3]^4, Rational[1, 120] Log[3]^5, Rational[1, 720] Log[3]^6, 
    Rational[1, 5040] Log[3]^7, Rational[1, 40320] Log[3]^8, 
    Rational[1, 362880] Log[3]^9, Rational[1, 3628800] Log[3]^10}, 0, 11, 1],
  Editable->False]], "Output",
 CellChangeTimes->{3.433895641662322*^9}]
}, Open  ]],

Cell["This means that any convergence takes place 2-adically.", "Text",
 CellChangeTimes->{{3.4339888089945974`*^9, 3.4339888200704556`*^9}, {
  3.4340294639896617`*^9, 3.434029465658862*^9}, {3.434034737204262*^9, 
  3.434034760869462*^9}, {3.4340348421142616`*^9, 3.4340348570902615`*^9}}],

Cell["And \"Log[3]\" isn't the real Log[3]; it's the 2-adic Log[3].", "Text",
 CellChangeTimes->{{3.4339887611032114`*^9, 3.43398878461211*^9}, {
  3.4339888384314203`*^9, 3.433988881908063*^9}, {3.4340294729752617`*^9, 
  3.4340295144400616`*^9}, {3.4340348700226617`*^9, 3.4340348790706615`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["2-adic Log[3]", "Subsection",
 CellChangeTimes->{{3.434413032895*^9, 3.4344130357966003`*^9}}],

Cell[TextData[{
 "How do we compute the 2-adic Log[3]?\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"Log", "[", 
    RowBox[{"1", "-", "x"}], "]"}], TraditionalForm]]],
 " has a 2-adic power series (that is the same as its real power series):"
}], "Text",
 CellChangeTimes->{{3.4339887611032114`*^9, 3.43398878461211*^9}, {
  3.4339888384314203`*^9, 3.433988881908063*^9}, {3.4340294729752617`*^9, 
  3.4340295144400616`*^9}, {3.4340348700226617`*^9, 3.4340348790706615`*^9}, {
  3.4340353382410617`*^9, 3.434035344075462*^9}, {3.434243514822*^9, 
  3.43424351746*^9}, {3.4344130414126*^9, 3.4344130427542*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{"Log", "[", 
    RowBox[{"1", "-", "x"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.433988862002718*^9, 3.4339888710194025`*^9}, {
  3.4340353317670617`*^9, 3.4340353577722616`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", "x"}], "-", 
   FractionBox[
    SuperscriptBox["x", "2"], "2"], "-", 
   FractionBox[
    SuperscriptBox["x", "3"], "3"], "-", 
   FractionBox[
    SuperscriptBox["x", "4"], "4"], "-", 
   FractionBox[
    SuperscriptBox["x", "5"], "5"], "-", 
   FractionBox[
    SuperscriptBox["x", "6"], "6"], "-", 
   FractionBox[
    SuperscriptBox["x", "7"], "7"], "-", 
   FractionBox[
    SuperscriptBox["x", "8"], "8"], "-", 
   FractionBox[
    SuperscriptBox["x", "9"], "9"], "-", 
   FractionBox[
    SuperscriptBox["x", "10"], "10"], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "x", "]"}], "11"],
    SeriesData[$CellContext`x, 0, {}, 1, 11, 1],
    Editable->False]}],
  SeriesData[$CellContext`x, 0, {-1, 
    Rational[-1, 2], 
    Rational[-1, 3], 
    Rational[-1, 4], 
    Rational[-1, 5], 
    Rational[-1, 6], 
    Rational[-1, 7], 
    Rational[-1, 8], 
    Rational[-1, 9], 
    Rational[-1, 10]}, 1, 11, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.433988868523434*^9, 3.4339888713157983`*^9}, {
  3.434035332063462*^9, 3.434035358115462*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "n"], 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "2"}], ")"}], "i"], "i"]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "20"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.433988977987231*^9, 3.4339890166903343`*^9}, 
   3.434035324544262*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "0", ",", 
   FractionBox["8", "3"], ",", 
   RowBox[{"-", 
    FractionBox["4", "3"]}], ",", 
   FractionBox["76", "15"], ",", 
   RowBox[{"-", 
    FractionBox["28", "5"]}], ",", 
   FractionBox["444", "35"], ",", 
   RowBox[{"-", 
    FractionBox["676", "35"]}], ",", 
   FractionBox["11836", "315"], ",", 
   RowBox[{"-", 
    FractionBox["4084", "63"]}], ",", 
   FractionBox["84100", "693"], ",", 
   RowBox[{"-", 
    FractionBox["152444", "693"]}], ",", 
   FractionBox["3695284", "9009"], ",", 
   RowBox[{"-", 
    FractionBox["978260", "1287"]}], ",", 
   FractionBox["9166172", "6435"], ",", 
   RowBox[{"-", 
    FractionBox["17191588", "6435"]}], ",", 
   FractionBox["551191324", "109395"], ",", 
   RowBox[{"-", 
    FractionBox["347329612", "36465"]}], ",", 
   FractionBox["12518899292", "692835"], ",", 
   RowBox[{"-", 
    FractionBox["23805608356", "692835"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.4339890055520773`*^9, 3.433989016815133*^9}, 
   3.434035325792262*^9}]
}, Open  ]],

Cell[TextData[{
 "Of course, in the real norm, this power series diverges for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "\[Equal]", 
    RowBox[{"-", "2"}]}], TraditionalForm]]],
 ", so we can't use it to compute the real Log[3].\nBut it does converge \
2-adically at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "\[Equal]", 
    RowBox[{"-", "2"}]}], TraditionalForm]]],
 ":"
}], "Text",
 CellChangeTimes->{{3.433988888397579*^9, 3.433988957364295*^9}, 
   3.434035378691862*^9, {3.434035442215062*^9, 3.434035442480262*^9}, {
   3.434413065733*^9, 3.4344130658422003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ArrayPlot", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"First", "[", 
         RowBox[{"RealDigits", "[", 
          RowBox[{
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"i", "=", "1"}], "n"], 
            FractionBox[
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "2"}], ")"}], "i"], "i"]}], ",", "2", ",", "200", 
           ",", "100"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "100"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"ArrayPlot", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"First", "[", 
         RowBox[{"PAdicDigits", "[", 
          RowBox[{
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"i", "=", "1"}], "n"], 
            FractionBox[
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "2"}], ")"}], "i"], "i"]}], ",", "2", ",", "200", 
           ",", "0"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "100"}], "}"}]}], "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "700"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4339890573278136`*^9, 3.433989126497327*^9}, {
  3.43398917460711*^9, 3.433989181705019*^9}, {3.433989252528111*^9, 
  3.433989255850868*^9}, {3.4340354446174617`*^9, 3.434035452963462*^9}, {
  3.434035489436262*^9, 3.4340355147238617`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[RasterBox[CompressedData["
1:eJzdlV1620YSRauyk9nSLCFf3rPNWdY4EeqeUxBtUSKgB9OWSBGN7rq/+M+f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       "], {{0, 0}, {200, 100}}, {0, 1}],
      Frame->Automatic,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}}], {192., -94.5}, ImageScaled[
     {0.5, 0.5}], {360., 180.}], InsetBox[
     GraphicsBox[RasterBox[CompressedData["
1:eJzdlFt6m7kRRBvZSbaUJcyX99lmlpWRxTp1mpLGJk2OLdGWRPIHGnXFv//4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       "], {{0, 0}, {200, 100}}, {0, 1}],
      Frame->Automatic,
      FrameLabel->{None, None},
      FrameTicks->{{None, None}, {None, None}}], {576., -94.5}, 
     ImageScaled[{0.5, 0.5}], {360., 180.}]}, {}},
  ContentSelectable->True,
  ImageSize->700,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.4340354827750616`*^9, 3.434035528795062*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Bit complexity", "Section",
 CellChangeTimes->{{3.433991569397258*^9, 3.4339915711288466`*^9}}],

Cell[TextData[{
 "How quickly can ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["3", 
    SuperscriptBox["2", "n"]], TraditionalForm]]],
 " be computed to accuracy ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 "?"
}], "Text",
 CellChangeTimes->{{3.4340295386668615`*^9, 3.434029557184062*^9}}],

Cell[TextData[{
 "Let ",
 Cell[BoxData[
  FormBox[
   RowBox[{"M", "(", "a", ")"}], TraditionalForm]]],
 " be the number of bit operations needed to multiply two ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 "-bit integers."
}], "Text",
 CellChangeTimes->{{3.4343289891745777`*^9, 3.434328991592578*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["3", 
     SuperscriptBox["2", "n"]], " ", "mod", " ", 
    SuperscriptBox["2", "a"]}], TraditionalForm]]],
 " can be computed by repeated squaring:  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[CenterEllipsis]", "(", 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox["3", "2"], ")"}], "2"], ")"}], "2"], 
      "\[CenterEllipsis]"}], ")"}], "2"], TraditionalForm]]],
 " (",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " times), where at each step we only keep the lowest ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 " bits.\nSince we're squaring ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 "-bit numbers ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " times, repeated squaring can be done in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    RowBox[{"n", " ", 
     RowBox[{"M", "(", "a", ")"}]}], ")"}], TraditionalForm]]],
 " bit operations."
}], "Text",
 CellChangeTimes->{{3.434029563938862*^9, 3.434029648522062*^9}, {
   3.434035745212062*^9, 3.434035780951662*^9}, 3.434328984463378*^9, {
   3.4343290156945777`*^9, 3.4343290780633774`*^9}, {3.4344131204734*^9, 
   3.434413126183*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Does the power series do any better?", "Text",
 CellChangeTimes->{{3.4340356280404615`*^9, 3.4340356332820616`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   SuperscriptBox["3", "x"], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "6"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4343290933981776`*^9, 3.4343291046457777`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "+", 
   RowBox[{
    RowBox[{"Log", "[", "3", "]"}], " ", "x"}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     RowBox[{"Log", "[", "3", "]"}], "2"], " ", 
    SuperscriptBox["x", "2"]}], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    SuperscriptBox[
     RowBox[{"Log", "[", "3", "]"}], "3"], " ", 
    SuperscriptBox["x", "3"]}], "+", 
   RowBox[{
    FractionBox["1", "24"], " ", 
    SuperscriptBox[
     RowBox[{"Log", "[", "3", "]"}], "4"], " ", 
    SuperscriptBox["x", "4"]}], "+", 
   RowBox[{
    FractionBox["1", "120"], " ", 
    SuperscriptBox[
     RowBox[{"Log", "[", "3", "]"}], "5"], " ", 
    SuperscriptBox["x", "5"]}], "+", 
   RowBox[{
    FractionBox["1", "720"], " ", 
    SuperscriptBox[
     RowBox[{"Log", "[", "3", "]"}], "6"], " ", 
    SuperscriptBox["x", "6"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "x", "]"}], "7"],
    SeriesData[$CellContext`x, 0, {}, 0, 7, 1],
    Editable->False]}],
  SeriesData[$CellContext`x, 0, {1, 
    Log[3], Rational[1, 2] Log[3]^2, Rational[1, 6] Log[3]^3, Rational[1, 24] 
    Log[3]^4, Rational[1, 120] Log[3]^5, Rational[1, 720] Log[3]^6}, 0, 7, 1],
  
  Editable->False]], "Output",
 CellChangeTimes->{{3.4343290994821777`*^9, 3.434329104801778*^9}}]
}, Open  ]],

Cell[TextData[{
 "To compute ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " bits of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["3", 
    SuperscriptBox["2", "n"]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " using the 2-adic power series for ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["3", "x"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ":\n\tUse the power series for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Log", "[", 
    RowBox[{"1", "-", "x"}], "]"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " to compute ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " bits of the 2-adic Log[3] by evaluating at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "\[Equal]", 
    RowBox[{"-", "2"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ".  This requires ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "-", "n"}], TraditionalForm]]],
 " terms.\n\tThen use the power series for ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["3", "x"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " (and the approximation of Log[3]) to compute ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " bits of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["3", 
    SuperscriptBox["2", "n"]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " by evaluating at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "\[Equal]", 
    SuperscriptBox["2", "n"]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ".  This requires ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[LeftCeiling]", 
    RowBox[{"a", "/", "n"}], "\[RightCeiling]"}], TraditionalForm]]],
 " terms."
}], "Text",
 CellChangeTimes->{{3.434035569353262*^9, 3.434035604593662*^9}, {
  3.434035635715662*^9, 3.434035660020462*^9}, {3.434035827502062*^9, 
  3.434035880074062*^9}, {3.4340360035012617`*^9, 3.434036024062062*^9}, {
  3.434036064154062*^9, 3.434036096524062*^9}}],

Cell[TextData[{
 "Each step involves evaluating a polynomial at an integer.\nIf ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "x", ")"}], TraditionalForm]]],
 " is a degree-",
 Cell[BoxData[
  FormBox["d", TraditionalForm]]],
 " polynomial with rational coefficients, computing ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " bits of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "r", ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " can be done in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    RowBox[{"d", " ", 
     RowBox[{"M", "(", "a", ")"}]}], ")"}], TraditionalForm]]],
 " bit operations."
}], "Text",
 CellChangeTimes->{{3.4340359051276617`*^9, 3.4340359752496614`*^9}, {
  3.434036138441262*^9, 3.434036138566062*^9}}],

Cell[TextData[{
 "In all, ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " bits of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["3", 
    SuperscriptBox["2", "n"]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " can be computed with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "-", "n", "+", 
       RowBox[{"a", "/", "n"}]}], ")"}], " ", 
     RowBox[{"M", "(", "a", ")"}]}], ")"}], TraditionalForm]]],
 " bit operations."
}], "Text",
 CellChangeTimes->{{3.4340359842040615`*^9, 3.434035990943262*^9}, {
  3.4340361190816617`*^9, 3.434036143136862*^9}}],

Cell[TextData[{
 "If ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 " grows linearly with ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 ", then this is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    RowBox[{"n", " ", 
     RowBox[{"M", "(", "n", ")"}]}], ")"}], TraditionalForm]]],
 ", so it's asymptotically the same as repeated squaring."
}], "Text",
 CellChangeTimes->{{3.434036179453662*^9, 3.434036209936062*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Generalizations", "Section",
 CellChangeTimes->{{3.433991569397258*^9, 3.4339915711288466`*^9}, {
   3.4340337640586615`*^9, 3.434033765291062*^9}, 3.4340388234674616`*^9}],

Cell["Other exponents:", "Text",
 CellChangeTimes->{{3.4341158792768*^9, 3.4341158821004*^9}}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Reverse", "[", 
     RowBox[{"IntegerDigits", "[", 
      RowBox[{
       RowBox[{"PowerMod", "[", 
        RowBox[{"3", ",", 
         RowBox[{
          SuperscriptBox["2", "n"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"17", "n"}], "-", "5"}], ")"}]}], ",", 
         SuperscriptBox["2", "700"]}], "]"}], ",", "2"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "0", ",", 
      RowBox[{
       SuperscriptBox["2", "8"], "-", "1"}]}], "}"}]}], "]"}], "]"}]], "Input",\

 CellChangeTimes->{{3.4341157034336*^9, 3.4341158216191998`*^9}, 
   3.434115854738*^9}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Reverse", "[", 
     RowBox[{"IntegerDigits", "[", 
      RowBox[{
       RowBox[{"PowerMod", "[", 
        RowBox[{"3", ",", 
         RowBox[{
          SuperscriptBox["2", "n"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["n", "2"], "+", 
            RowBox[{"17", " ", "n"}], "-", "5"}], ")"}]}], ",", 
         SuperscriptBox["2", "700"]}], "]"}], ",", "2"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "0", ",", 
      RowBox[{
       SuperscriptBox["2", "8"], "-", "1"}]}], "}"}]}], "]"}], "]"}]], "Input",\

 CellChangeTimes->{{3.4341157034336*^9, 3.4341158421331997`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["5", 
    SuperscriptBox["2", "n"]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " in binary:"
}], "Text",
 CellChangeTimes->{{3.434038664425462*^9, 3.434038674830662*^9}}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     RowBox[{"PowerMod", "[", 
      RowBox[{"5", ",", 
       SuperscriptBox["2", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           SuperscriptBox["2", "8"], "-", "1"}]}], "]"}]], ",", 
       SuperscriptBox["2", "700"]}], "]"}], ",", "2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.434038677233062*^9, 3.434038717044262*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["7", 
    SuperscriptBox["2", "n"]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " in binary:"
}], "Text",
 CellChangeTimes->{{3.434038664425462*^9, 3.434038674830662*^9}, {
  3.434038738073062*^9, 3.4340387381978617`*^9}}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     RowBox[{"PowerMod", "[", 
      RowBox[{"7", ",", 
       SuperscriptBox["2", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           SuperscriptBox["2", "8"], "-", "1"}]}], "]"}]], ",", 
       SuperscriptBox["2", "700"]}], "]"}], ",", "2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.434038677233062*^9, 3.434038728915862*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["9", 
    SuperscriptBox["2", "n"]], TraditionalForm]]],
 " in binary:"
}], "Text",
 CellChangeTimes->{{3.434038664425462*^9, 3.434038674830662*^9}, {
  3.434038738073062*^9, 3.4340387654042616`*^9}}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     RowBox[{"PowerMod", "[", 
      RowBox[{"9", ",", 
       SuperscriptBox["2", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           SuperscriptBox["2", "8"], "-", "1"}]}], "]"}]], ",", 
       SuperscriptBox["2", "700"]}], "]"}], ",", "2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.434038677233062*^9, 3.4340387547026615`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", 
    SuperscriptBox["3", "n"]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " in ternary:"
}], "Text",
 CellChangeTimes->{{3.4340388350426617`*^9, 3.434038847585062*^9}}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     RowBox[{"PowerMod", "[", 
      RowBox[{"2", ",", 
       SuperscriptBox["3", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           SuperscriptBox["2", "8"], "-", "1"}]}], "]"}]], ",", 
       SuperscriptBox["3", "700"]}], "]"}], ",", "3"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.434038677233062*^9, 3.4340387547026615`*^9}, {
  3.4340387998958616`*^9, 3.434038813514662*^9}, {3.434039065002262*^9, 
  3.4340390693234615`*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["4", 
    SuperscriptBox["3", "n"]], TraditionalForm]]],
 " in ternary:"
}], "Text",
 CellChangeTimes->{{3.4340388350426617`*^9, 3.434038847585062*^9}, {
  3.434038880033062*^9, 3.4340388802202616`*^9}, {3.434039095718662*^9, 
  3.434039095765462*^9}}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     RowBox[{"PowerMod", "[", 
      RowBox[{"4", ",", 
       SuperscriptBox["3", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           SuperscriptBox["2", "8"], "-", "1"}]}], "]"}]], ",", 
       SuperscriptBox["3", "700"]}], "]"}], ",", "3"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.434038677233062*^9, 3.4340387547026615`*^9}, {
   3.4340387998958616`*^9, 3.434038813514662*^9}, 3.4340388513446617`*^9, {
   3.434038882529062*^9, 3.4340388826226616`*^9}, {3.434039081787862*^9, 
   3.4340390819282618`*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["5", 
    SuperscriptBox["3", "n"]], TraditionalForm]]],
 " in ternary:"
}], "Text",
 CellChangeTimes->{{3.4340388350426617`*^9, 3.434038847585062*^9}, {
  3.434038880033062*^9, 3.4340388802202616`*^9}}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     RowBox[{"PowerMod", "[", 
      RowBox[{"5", ",", 
       SuperscriptBox["3", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           SuperscriptBox["2", "8"], "-", "1"}]}], "]"}]], ",", 
       SuperscriptBox["3", "700"]}], "]"}], ",", "3"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.434038677233062*^9, 3.4340387547026615`*^9}, {
   3.4340387998958616`*^9, 3.434038813514662*^9}, 3.4340388513446617`*^9, {
   3.434038882529062*^9, 3.4340388826226616`*^9}, {3.4340389419338617`*^9, 
   3.4340389442426615`*^9}, {3.434039088917062*^9, 3.434039089026262*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", 
    SuperscriptBox["5", "n"]], TraditionalForm]]],
 " in base 5:"
}], "Text",
 CellChangeTimes->{{3.434039020339462*^9, 3.434039028888262*^9}, {
  3.434039142846262*^9, 3.434039152518262*^9}}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     RowBox[{"PowerMod", "[", 
      RowBox[{"2", ",", 
       SuperscriptBox["5", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           SuperscriptBox["2", "8"], "-", "1"}]}], "]"}]], ",", 
       SuperscriptBox["5", "700"]}], "]"}], ",", "5"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.434039129305462*^9, 3.4340391337670617`*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["3", 
    SuperscriptBox["5", "n"]], TraditionalForm]]],
 " in base 5:"
}], "Text",
 CellChangeTimes->{{3.434039020339462*^9, 3.434039028888262*^9}, {
  3.434039142846262*^9, 3.434039165045062*^9}}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     RowBox[{"PowerMod", "[", 
      RowBox[{"3", ",", 
       SuperscriptBox["5", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           SuperscriptBox["2", "8"], "-", "1"}]}], "]"}]], ",", 
       SuperscriptBox["5", "700"]}], "]"}], ",", "5"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.434039129305462*^9, 3.434039162127862*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["\<\
Why do we see vertical stripes instead of a solid color triangle?\
\>", "Text",
 CellChangeTimes->{{3.4340391889598618`*^9, 3.4340391952778616`*^9}, {
  3.434039496092662*^9, 3.434039502582262*^9}, {3.4340395502714615`*^9, 
  3.434039580566662*^9}, {3.434039661297662*^9, 3.4340396895804615`*^9}, {
  3.4340397692340617`*^9, 3.434039770045262*^9}, {3.434039818030862*^9, 
  3.434039820682862*^9}, {3.434039902723262*^9, 3.4340399101176615`*^9}, {
  3.434040210979262*^9, 3.4340402303544617`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     RowBox[{"PowerMod", "[", 
      RowBox[{"2", ",", 
       SuperscriptBox["5", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{
           SuperscriptBox["2", "8"], "-", "1"}]}], "]"}]], ",", 
       SuperscriptBox["5", "700"]}], "]"}], ",", "5"}], "]"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzkurvRRr2ybrXgkAiRkAMhnCpsEiQIQsDEPCGAwXJ2oRove2jMR99POzK6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   "], {{0, 0}, {700, 256}}, {0, 1}],
  Frame->Automatic,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}}]], "Output",
 CellChangeTimes->{3.4343292751537776`*^9}]
}, Open  ]],

Cell[TextData[{
 "In general ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"EulerPhi", "[", 
     SuperscriptBox["p", 
      RowBox[{"n", "+", "1"}]], "]"}], "\[Equal]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"p", "-", "1"}], ")"}], 
     SuperscriptBox["p", "n"]}]}], TraditionalForm]]],
 ", so Euler's theorem gives ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"p", "-", "1"}], ")"}], 
      SuperscriptBox["p", "n"]}]], "\[Congruent]", 
    RowBox[{"1", " ", "mod", " ", 
     SuperscriptBox["p", 
      RowBox[{"n", "+", "1"}]]}]}], TraditionalForm]]],
 ".\nSo ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"p", "-", "1"}], ")"}], 
      SuperscriptBox["p", "n"]}]], "\[Rule]", "1"}], TraditionalForm]]],
 " as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "\[Rule]", "\[Infinity]"}], TraditionalForm]]],
 ":"
}], "Text",
 CellChangeTimes->{{3.4340391889598618`*^9, 3.4340391952778616`*^9}, {
  3.434039496092662*^9, 3.434039502582262*^9}, {3.4340395502714615`*^9, 
  3.434039580566662*^9}, {3.434039661297662*^9, 3.4340396895804615`*^9}, {
  3.4340397692340617`*^9, 3.434039770045262*^9}, {3.434039818030862*^9, 
  3.434039820682862*^9}, {3.434039902723262*^9, 3.4340399149224615`*^9}, {
  3.434039946824462*^9, 3.434039967260462*^9}, {3.4340401820100617`*^9, 
  3.4340401890924616`*^9}}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     RowBox[{"PowerMod", "[", 
      RowBox[{"2", ",", 
       RowBox[{"4", " ", 
        SuperscriptBox["5", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", 
           RowBox[{
            SuperscriptBox["2", "8"], "-", "1"}]}], "]"}]]}], ",", 
       SuperscriptBox["5", "700"]}], "]"}], ",", "5"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.434039129305462*^9, 3.434039162127862*^9}, {
  3.4340401427448616`*^9, 3.4340401595616617`*^9}}],

Cell[TextData[{
 "So ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["k", 
     SuperscriptBox["p", "n"]], "\[Rule]", 
    SuperscriptBox["1", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"p", "-", "1"}], ")"}]}]]}], TraditionalForm]]],
 " as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "\[Rule]", "\[Infinity]"}], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.4340402407440615`*^9, 3.4340402417112617`*^9}, {
   3.434040297450062*^9, 3.434040303206462*^9}, {3.4340404219380617`*^9, 
   3.434040482637662*^9}, 3.4343293097545776`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[TextData[{
 "Which ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"p", "-", "1"}], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "th root of unity?  the one that is congruent to ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]]],
 " modulo ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]]],
 ".\n(This root of unity is called the Teichm\[UDoubleDot]ller representative \
of ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]]],
 ".)"
}], "Text",
 CellChangeTimes->{{3.4340402407440615`*^9, 3.4340402417112617`*^9}, {
  3.434040297450062*^9, 3.434040303206462*^9}, {3.4340404219380617`*^9, 
  3.434040482637662*^9}, {3.4343293097545776`*^9, 3.4343293402993774`*^9}}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{
   RowBox[{"Reverse", "/@", 
    RowBox[{"IntegerDigits", "[", 
     RowBox[{
      RowBox[{"PowerMod", "[", 
       RowBox[{"2", ",", 
        SuperscriptBox["5", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "50"}], "]"}]], ",", 
        SuperscriptBox["5", "51"]}], "]"}], ",", "5"}], "]"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "150"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.434039129305462*^9, 3.4340391337670617`*^9}, {
  3.434043393452262*^9, 3.4340434164934616`*^9}, {3.4340434909210615`*^9, 
  3.4340434946338615`*^9}, {3.434364927139345*^9, 3.434364933831745*^9}}],

Cell[TextData[{
 "Solve ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["x", 
     RowBox[{"p", "-", "1"}]], "\[Congruent]", "1"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " modulo ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", "a"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"a", "=", "1"}], ",", "2", ",", "\[Ellipsis]"}], 
   TraditionalForm]],
  FormatType->"TraditionalForm"],
 ":"
}], "Text",
 CellChangeTimes->{{3.434364887406145*^9, 3.434364916000945*^9}, {
  3.434365064200945*^9, 3.4343650824373455`*^9}}],

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", "=", "5"}], "}"}], ",", 
   RowBox[{"ArrayPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Reverse", "[", 
        RowBox[{"IntegerDigits", "[", 
         RowBox[{
          RowBox[{"First", "[", 
           RowBox[{"Select", "[", 
            RowBox[{
             RowBox[{"x", "/.", "\[InvisibleSpace]", 
              RowBox[{"Solve", "[", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", 
                  RowBox[{"p", "-", "1"}]], "\[Equal]", "1"}], "&&", 
                RowBox[{"Modulus", "\[Equal]", 
                 SuperscriptBox["p", "a"]}]}], "]"}]}], ",", 
             RowBox[{
              RowBox[{
               RowBox[{"Mod", "[", 
                RowBox[{
                 RowBox[{"#1", "-", "2"}], ",", "p"}], "]"}], "\[Equal]", 
               "0"}], "&"}]}], "]"}], "]"}], ",", "5"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", "51"}], "}"}]}], "]"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "150"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.434043233770662*^9, 3.434043254799462*^9}, {
  3.4340432943922615`*^9, 3.434043326231862*^9}, {3.434043422858262*^9, 
  3.4340434853362617`*^9}}],

Cell["\<\
The limit is a 2-adic unit that we must multiply the power series by.\
\>", "Text",
 CellChangeTimes->{{3.4343649513973455`*^9, 3.434364977667745*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Other integer sequences", "Subsection",
 CellChangeTimes->{{3.434044362810662*^9, 3.434044366195862*^9}, 
   3.4343294319805775`*^9, 3.434329483663378*^9, 3.434365329650545*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     RowBox[{"Fibonacci", "[", 
      SuperscriptBox["2", 
       RowBox[{"Range", "[", 
        RowBox[{"0", ",", "25"}], "]"}]], "]"}], ",", "2", ",", "100"}], 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4340443802670617`*^9, 3.4340444528850617`*^9}}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzFU0lywzAMA/uM3vKlPiHTe/9/a2wJCxXlkqmnzsSWLZEEQPB2//m6fwD4
fPy/H38Uqup8HotjeXw5PtS5XedrtcVca5/RGDt8zP2xjRY0Asb38RvVCGIe
nLszBY/AKJTrFY9iaWfzU7VmJN9ZfKpQ4rPlAalF5jpehOkUrKzsOjfl3fGA
9BIfEeSxxBxAmJcySMSFBxHqfEUmlchTqbqkULc2PNwTqiGAvCGfIBirQAIS
fOFRslNahInUUNtoAcdQmM7KY7HJ0iMbPg3hEN1IZDcfarA0iCYmdllJ41RB
QQ3Z9COdTXd4AruZnNyf3KKWM3lIfVabMiGDEMCCYp6M0QA6DzyLEmFAJgzZ
u0ge0VRBZd2pUDL1QcipLgQwjoZVqc6DurqWJGRAZw2JSJG1tF5thvNtIVEL
NMOyUFkzbCVvN5gdsMs029iujg1REZZdkasPnlUW0gRrAAxNOWMYwu/VM1ga
ZAWHp35hRzQxYD08H6Fzm5TKHPXmFfRlzvezvajhebvsciMvrHF1gfpz6f+t
xi9JmQhk
   "], {{0, 0}, {100, 26}}, {0, 1}],
  Frame->Automatic,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}}]], "Output",
 CellChangeTimes->{3.4343294687185774`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a_", ",", "b_", ",", "s_"}], "}"}], ",", "0", ",", "m_"}], 
   "]"}], ":=", 
  RowBox[{"Mod", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", 
         RowBox[{"2", " ", "b"}]}], ")"}]}], ",", 
      RowBox[{"s", "+", 
       RowBox[{"a", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "a"}], "-", "b"}], ")"}]}]}], ",", "1"}], "}"}], 
    ",", "m"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a_", ",", "b_", ",", "s_"}], "}"}], ",", "1", ",", "m_"}], 
   "]"}], ":=", 
  RowBox[{"Mod", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "s"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "+", "b"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", 
          RowBox[{"2", " ", "b"}]}], ")"}]}]}], ",", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", 
         RowBox[{"2", " ", "b"}]}], ")"}]}], ",", 
      RowBox[{"-", "1"}]}], "}"}], ",", "m"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"FibonacciMod", "[", 
   RowBox[{"n_", ",", "m_"}], "]"}], ":=", 
  RowBox[{"First", "[", 
   RowBox[{"Fold", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"##1", ",", "m"}], "]"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"Rest", "[", 
      RowBox[{"IntegerDigits", "[", 
       RowBox[{"n", ",", "2"}], "]"}], "]"}]}], "]"}], "]"}]}], "\n", 
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Reverse", "[", 
     RowBox[{"IntegerDigits", "[", 
      RowBox[{
       RowBox[{"FibonacciMod", "[", 
        RowBox[{
         SuperscriptBox["2", "n"], ",", 
         SuperscriptBox["2", "700"]}], "]"}], ",", "2"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", 
      RowBox[{
       SuperscriptBox["2", "8"], "-", "1"}]}], "}"}]}], "]"}], 
  "]"}]}], "Input",
 CellChangeTimes->{
  3.434365677483745*^9, {3.4343657087617455`*^9, 3.434365712380945*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     RowBox[{"LucasL", "[", 
      SuperscriptBox["2", 
       RowBox[{"Range", "[", 
        RowBox[{"0", ",", "25"}], "]"}]], "]"}], ",", "2", ",", "100"}], 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4340443802670617`*^9, 3.434044476955862*^9}, {
  3.434329442853778*^9, 3.434329451152978*^9}}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJy1VElywzAME/qM3vqlPiHTe/9/q2uRAKgl43ZiOc4oWoiFZD4e35+Pt9ba
+/F+tWcD59PiPZ5jgmP8TjAcO1eQq+fJ1lcBLGLrYD8BBJpO9xksWF/tFAge
AFuQjQqq6ahxH9zKkPq9l7FWkW45QwDGCMlFUH9SkcsdGbZpCiIPSYzGXlIR
6XOAyACNy4DC3GMsVDBqTWSE1Cft9+yvMGYVChcUUo2TSRzaSNwLKlRLZopZ
zmSz7ET0mgqrJUs/5BWLVNXN3LEcnqlgYZpn9MnYEEa3i8l7FVAwlYr3Qb2m
SraGxOhWUWFlT+mlR5iHTHDOJACTjqo+wzSFyLAGoRyzAhIWk4aiIgVnPHNr
LFfdUq9mevSvMqlwoTUxGuRCRvphdysG+WhinUYfrA9tfzGh8lmF9aZKJVPP
FlTLGYta1qrnQYXvWMZhpNQKWrESktluq1SIuwWFnML/hqkoX68covriwAPG
fdGJcS8Axsa6CeN+CPwAWKUHxg==
   "], {{0, 0}, {100, 26}}, {0, 1}],
  Frame->Automatic,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}}]], "Output",
 CellChangeTimes->{3.4343294695141773`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["2", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "20"}], "]"}]], "!"}], 
      SuperscriptBox["2", 
       RowBox[{
        SuperscriptBox["2", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "20"}], "]"}]], "-", "1"}]]], ",", "2", ",", 
     "100"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.434044637838662*^9, 3.4340446416606617`*^9}, {
  3.4343295498541775`*^9, 3.4343295929257774`*^9}, {3.4343296542347775`*^9, 
  3.4343297102387776`*^9}}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJy9lMF1wzAMQ8nu0AGyUkfI67373+pawgckJ7c0ynNsxSJBgkBu95+v+0dV
fR7Xd/2tru7jiofj8dyOt3z3eWAsbUqRVfnqDBjP/RhjHh2/lD9zN5Oe0cDO
nKWcI2DmvGLonaumNvU5ehDQnquoZhZ5wWgDGExVl1pXwSLMW+FC0pWrUuVF
6qVrE8LYOufm3hnKjtE5JZEUnDkIGSy3ij59cMGoHFsZWRVKQ2pI+a002Fq4
CYyYZhYsFW4CJ94K7nZD1kNiQGtztirLpcnQ6mYpdWMSN1uAXa41wbnbiCE9
yzGC1pkvVDciJ5bU4dIQLbRa9SBhPSbqsx41JENleC5kFbaU39J65jmM4l6V
KUWHxGOhfU/S5rKsr421BmRBqMroGDEmueG2B+2nW5a/COzB4CNVDI343jfQ
VPREN+Ea7IBHrJAsexlzyA32XrIQ8WvSPcP49/UGiLdg/AKupQc0
   "], {{0, 0}, {100, 21}}, {0, 1}],
  Frame->Automatic,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}}]], "Output",
 CellChangeTimes->{3.434329712906378*^9, 3.4343653650313454`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     RowBox[{"CatalanNumber", "[", 
      SuperscriptBox["2", 
       RowBox[{"Range", "[", 
        RowBox[{"0", ",", "20"}], "]"}]], "]"}], ",", "2", ",", "100"}], 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4340443802670617`*^9, 3.434044480965062*^9}, {
  3.434044537218662*^9, 3.434044537515062*^9}}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJy9VMt1wzAMA7tDB+hKHSGv9+5/qysRH0Y59JDUsaxnSSZIEMjH7fvz9gbg
/Rpf16jrrsK69wPrt6e1+bu2NtYr9rwn76PHjlM9c+3E6AV0MEVHHyPWPlX+
fkfjYZ84MdAbVU5JKQdWpw1u8s0EQOXcYXSdfJaqJaiSZJgG6MpBEkXggYH5
VecCwTpx9cN7PukLRx3QqrEmyTzUtaj9LhdBxYM6BGI+VLm6MvifEgEif4Mm
RvBnPoK6VLGSTy6DWcWbXDkVK0C0U8omLoSoSKF6KywwhkVCIJWAFoULskLD
LezW8Icco5hhaPu2nDV5IrvxauckRvfIzEZn9a8CQYcH4vs4zrSi50EOs5fY
8DjiULxLzPYjMdSm6Y60rbAHRkCHsi036yp0FA0zq1aXPaTAXsk2hLEA81xB
dmIqjhxsq/3lEiMMd1fUMy4585lBD4wXBifGyxH+A6J+ACeQB0k=
   "], {{0, 0}, {100, 21}}, {0, 1}],
  Frame->Automatic,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}}]], "Output",
 CellChangeTimes->{{3.4340445361578617`*^9, 3.434044549152662*^9}, 
   3.4343294648809776`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<SequenceIdentification`\>\"", "]"}], "\n", 
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Reverse", "/@", 
   RowBox[{"IntegerDigits", "[", 
    RowBox[{
     RowBox[{"MotzkinNumber", "[", 
      SuperscriptBox["2", 
       RowBox[{"Range", "[", 
        RowBox[{"0", ",", "16"}], "]"}]], "]"}], ",", "2", ",", "100"}], 
    "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4340446425186615`*^9, 3.4340446535946617`*^9}, {
   3.4340446853094616`*^9, 3.4340446859646616`*^9}, 3.4343297404715776`*^9}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJy9k0tOxEAMRF3cgCNwJY4wYs/9dySK65U9SCxGCh0lSn9cH9v98fj+fLxV
1fvxftU5pDqfHsfsnOr6XD/H91pSH6hrsVjpwz1pjAb8xeE/iUjPzTLwenni
SpowVZFq5EEVpIqhGvqx4ZnpUAXg9IFbMiD2NbVKFlyEKzEkqffgsGfc2BC7
Q5yFCC+7Ci4bhi1klgCd3hm6YZaLQQ/gsAmWD0VeegsA1Lu6a0F4o350xcrV
7trgTr7ZMaPhOQRIzhobXrtBlQZYMuzSpC2Wuaf+mw2E16dgzA4NjrCQJDQX
RGHNXa1ErKbal90JqbUYnpVr91vqvBKVOG7ki4M+kBvxdaw/OITkm0aX6d5x
P8N/UOgHPG8GPg==
   "], {{0, 0}, {100, 17}}, {0, 1}],
  Frame->Automatic,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}}]], "Output",
 CellChangeTimes->{3.434044791816662*^9}]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"SlideShow",
WindowSize->{1264, 709},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"6.0 for Microsoft Windows (64-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "SlideShowHeader"->{
  Cell[590, 23, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1672, 54, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[3340, 106, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[4424, 139, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[6676, 204, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[12889, 372, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[15700, 441, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[126150, 2313, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[236449, 4165, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[238485, 4227, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[241853, 4317, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[246691, 4475, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[248312, 4529, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[250941, 4612, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[253837, 4691, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[258604, 4842, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[262355, 4945, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[265741, 5044, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[279190, 5370, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[281356, 5451, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[287105, 5652, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[288941, 5714, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[291339, 5799, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[294276, 5892, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[295895, 5950, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[505350, 9448, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[508898, 9560, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[513885, 9716, 64, 1, 4, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"]},
 "Info3433841459-1533185"->{
  Cell[7297, 226, 1317, 23, 120, "Print",
   CellTags->"Info3433841459-1533185"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"SlideShowHeader", 518210, 9837},
 {"Info3433841459-1533185", 520738, 9894}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[657, 26, 291, 7, 203, "Title"],
Cell[951, 35, 224, 3, 74, "Subtitle"],
Cell[1178, 40, 457, 9, 99, "Subsubtitle"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1672, 54, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1761, 59, 98, 1, 105, "Section"],
Cell[1862, 62, 283, 6, 90, "Text"],
Cell[2148, 70, 498, 11, 48, "Input"],
Cell[2649, 83, 203, 4, 41, "Text"],
Cell[2855, 89, 436, 11, 48, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3340, 106, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[3407, 109, 289, 7, 41, "Text"],
Cell[3699, 118, 688, 16, 48, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4424, 139, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[4513, 144, 104, 1, 54, "Subsection"],
Cell[4620, 147, 780, 16, 90, "Text"],
Cell[5403, 165, 252, 5, 41, "Text"],
Cell[5658, 172, 294, 7, 42, "Text"],
Cell[5955, 181, 672, 17, 33, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6676, 204, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[6743, 207, 407, 11, 44, "Text"],
Cell[CellGroupData[{
Cell[7175, 222, 119, 2, 43, "Input"],
Cell[7297, 226, 1317, 23, 120, "Print",
 CellTags->"Info3433841459-1533185"]
}, Open  ]],
Cell[8629, 252, 927, 26, 66, "Text"],
Cell[9559, 280, 384, 5, 29, "Text"],
Cell[9946, 287, 282, 7, 33, "Input"],
Cell[10231, 296, 222, 5, 31, "Input"],
Cell[10456, 303, 254, 5, 31, "Input"],
Cell[10713, 310, 431, 9, 33, "Input"],
Cell[11147, 321, 525, 12, 29, "Text"],
Cell[11675, 335, 296, 7, 33, "Input"],
Cell[11974, 344, 332, 9, 52, "Input"],
Cell[12309, 355, 170, 3, 31, "Input"],
Cell[12482, 360, 370, 7, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12889, 372, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[12956, 375, 826, 15, 83, "Text"],
Cell[13785, 392, 727, 15, 50, "Text"],
Cell[14515, 409, 481, 13, 33, "Input"],
Cell[14999, 424, 664, 12, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15700, 441, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[15789, 446, 97, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[15911, 451, 481, 13, 33, "Input"],
Cell[16395, 466, 107380, 1763, 156, "Output"]
}, Open  ]],
Cell[123790, 2232, 121, 1, 29, "Text"],
Cell[123914, 2235, 539, 12, 50, "Text"],
Cell[124456, 2249, 1325, 45, 68, "Text"],
Cell[125784, 2296, 317, 11, 32, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[126150, 2313, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[126239, 2318, 152, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[126416, 2324, 483, 13, 33, "Input"],
Cell[126902, 2339, 107382, 1763, 156, "Output"]
}, Open  ]],
Cell[234299, 4105, 268, 5, 47, "Text"],
Cell[234570, 4112, 842, 21, 78, "Input"],
Cell[235415, 4135, 618, 15, 47, "Text"],
Cell[236036, 4152, 364, 7, 47, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[236449, 4165, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[236538, 4170, 105, 1, 36, "Subsection"],
Cell[236646, 4173, 1427, 39, 131, "Input"],
Cell[238076, 4214, 360, 7, 65, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[238485, 4227, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[238552, 4230, 2836, 70, 198, "Input"],
Cell[241391, 4302, 425, 10, 68, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[241853, 4317, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[241942, 4322, 101, 1, 36, "Subsection"],
Cell[242046, 4325, 476, 6, 29, "Text"],
Cell[242525, 4333, 1332, 41, 126, "Text"],
Cell[243860, 4376, 456, 14, 45, "Input"],
Cell[244319, 4392, 175, 2, 29, "Text"],
Cell[244497, 4396, 561, 14, 38, "Input"],
Cell[245061, 4412, 247, 10, 29, "Text"],
Cell[245311, 4424, 275, 6, 31, "Input"],
Cell[245589, 4432, 385, 12, 47, "Text"],
Cell[245977, 4446, 235, 6, 31, "Input"],
Cell[246215, 4454, 427, 15, 31, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[246691, 4475, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[246758, 4478, 261, 7, 47, "Text"],
Cell[247022, 4487, 186, 5, 48, "Input"],
Cell[247211, 4494, 200, 6, 47, "Text"],
Cell[247414, 4502, 641, 17, 72, "Input"],
Cell[248058, 4521, 217, 3, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[248312, 4529, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[248401, 4534, 107, 1, 36, "Subsection"],
Cell[248511, 4537, 198, 6, 29, "Text"],
Cell[248712, 4545, 529, 15, 45, "Input"],
Cell[249244, 4562, 388, 9, 29, "Text"],
Cell[249635, 4573, 366, 11, 33, "Input"],
Cell[250004, 4586, 427, 9, 29, "Text"],
Cell[250434, 4597, 458, 9, 47, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[250941, 4612, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[251030, 4617, 111, 1, 28, "Subsubsection"],
Cell[251144, 4620, 147, 2, 29, "Text"],
Cell[251294, 4624, 1203, 31, 88, "Text"],
Cell[252500, 4657, 749, 19, 29, "Text"],
Cell[253252, 4678, 536, 7, 29, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[253837, 4691, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[253926, 4696, 99, 1, 71, "Section"],
Cell[254028, 4699, 1110, 32, 53, "Text"],
Cell[255141, 4733, 1425, 40, 65, "Text"],
Cell[256569, 4775, 517, 15, 52, "Input"],
Cell[257089, 4792, 135, 2, 31, "Input"],
Cell[257227, 4796, 179, 3, 31, "Input"],
Cell[257409, 4801, 126, 2, 31, "Input"],
Cell[257538, 4805, 1017, 31, 50, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[258604, 4842, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[258671, 4845, 1114, 26, 49, "Text"],
Cell[259788, 4873, 1855, 49, 87, "Text"],
Cell[261646, 4924, 118, 2, 31, "Input"],
Cell[261767, 4928, 116, 2, 31, "Input"],
Cell[261886, 4932, 432, 8, 65, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[262355, 4945, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[262422, 4948, 372, 7, 29, "Text"],
Cell[CellGroupData[{
Cell[262819, 4959, 235, 6, 31, "Input"],
Cell[263057, 4967, 2040, 61, 82, "Output"]
}, Open  ]],
Cell[265112, 5031, 291, 3, 29, "Text"],
Cell[265406, 5036, 298, 3, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[265741, 5044, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[265830, 5049, 100, 1, 36, "Subsection"],
Cell[265933, 5052, 607, 12, 47, "Text"],
Cell[CellGroupData[{
Cell[266565, 5068, 319, 8, 31, "Input"],
Cell[266887, 5078, 1150, 39, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[268074, 5122, 436, 14, 53, "Input"],
Cell[268513, 5138, 1046, 31, 113, "Output"]
}, Open  ]],
Cell[269574, 5172, 578, 16, 65, "Text"],
Cell[CellGroupData[{
Cell[270177, 5192, 1547, 41, 153, "Input"],
Cell[271727, 5235, 7402, 128, 203, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[279190, 5370, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[279279, 5375, 101, 1, 71, "Section"],
Cell[279383, 5378, 302, 11, 32, "Text"],
Cell[279688, 5391, 312, 10, 29, "Text"],
Cell[280003, 5403, 1304, 42, 74, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[281356, 5451, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[281423, 5454, 122, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[281570, 5459, 236, 6, 31, "Input"],
Cell[281809, 5467, 1337, 40, 79, "Output"]
}, Open  ]],
Cell[283161, 5510, 1994, 67, 107, "Text"],
Cell[285158, 5579, 800, 26, 65, "Text"],
Cell[285961, 5607, 663, 23, 32, "Text"],
Cell[286627, 5632, 441, 15, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[287105, 5652, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[287194, 5657, 178, 2, 71, "Section"],
Cell[287375, 5661, 94, 1, 29, "Text"],
Cell[287472, 5664, 693, 21, 55, "Input"],
Cell[288168, 5687, 724, 21, 77, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[288941, 5714, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[289008, 5717, 242, 8, 32, "Text"],
Cell[289253, 5727, 494, 14, 40, "Input"],
Cell[289750, 5743, 293, 9, 32, "Text"],
Cell[290046, 5754, 494, 14, 40, "Input"],
Cell[290543, 5770, 260, 8, 32, "Text"],
Cell[290806, 5780, 496, 14, 40, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[291339, 5799, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[291406, 5802, 245, 8, 32, "Text"],
Cell[291654, 5812, 598, 16, 40, "Input"],
Cell[292255, 5830, 312, 9, 32, "Text"],
Cell[292570, 5841, 676, 17, 40, "Input"],
Cell[293249, 5860, 263, 8, 32, "Text"],
Cell[293515, 5870, 724, 17, 40, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[294276, 5892, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[294343, 5895, 258, 8, 32, "Text"],
Cell[294604, 5905, 496, 14, 40, "Input"],
Cell[295103, 5921, 258, 8, 32, "Text"],
Cell[295364, 5931, 494, 14, 40, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[295895, 5950, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[295962, 5953, 506, 8, 29, "Text"],
Cell[CellGroupData[{
Cell[296493, 5965, 428, 13, 40, "Input"],
Cell[296924, 5980, 205767, 3376, 156, "Output"]
}, Open  ]],
Cell[502706, 9359, 1446, 45, 55, "Text"],
Cell[504155, 9406, 580, 16, 40, "Input"],
Cell[504738, 9424, 575, 19, 32, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[505350, 9448, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[505417, 9451, 698, 21, 47, "Text"],
Cell[506118, 9474, 651, 15, 55, "Input"],
Cell[506772, 9491, 617, 23, 29, "Text"],
Cell[507392, 9516, 1305, 34, 143, "Input"],
Cell[508700, 9552, 161, 3, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[508898, 9560, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[508987, 9565, 183, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[509195, 9571, 379, 10, 33, "Input"],
Cell[509577, 9583, 798, 16, 120, "Output"]
}, Open  ]],
Cell[510390, 9602, 2226, 75, 136, "Input"],
Cell[CellGroupData[{
Cell[512641, 9681, 423, 11, 33, "Input"],
Cell[513067, 9694, 757, 15, 120, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[513885, 9716, 64, 1, 4, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[513974, 9721, 651, 18, 52, "Input"],
Cell[514628, 9741, 742, 14, 102, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[515407, 9760, 430, 11, 33, "Input"],
Cell[515840, 9773, 772, 15, 102, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[516649, 9793, 535, 12, 54, "Input"],
Cell[517187, 9807, 621, 13, 89, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
